﻿' GPXファイルを書き換えるクラス

Imports System.Xml

Public Class GPXCHANGE
    Private inpuFileName As String ' 入力ファイル名
    Private outputFileName As String ' 出力ファイル名
    Private changeMode As Integer ' 変換モード　' 0 - 0m変換　1-削除

    Public flagBusy As Boolean = False    ' Thread実行中
    Public threadSub As System.Threading.Thread = Nothing

    ''' <summary>
    ''' GPXファイル書き換え実行のエントリーポイント
    ''' </summary>
    ''' <param name="inFile">変更元GPXファイル名</param>
    ''' <param name="outFile">変更後のGPXファイル名</param>
    ''' <param name="mode">変更モード 0-0mに変更　1-標高情報を削除</param>
    Public Sub GPXChange(inFile As String, outFile As String, mode As Integer)
        inpuFileName = inFile
        outputFileName = outFile
        changeMode = mode

        ' フォアグラウンドで処理すると処理中はWindowが固まって
        ' 「応答していません」が出るのが嫌なので
        ' thread起してバックグラウンドで実行する
        threadSub = New Threading.Thread(AddressOf GPXChangeTh)
        threadSub.IsBackground = True
        threadSub.Start()
    End Sub

    ''' <summary>
    ''' GPXファイル書き換え実行のthread (処理本体)
    ''' </summary>
    Private Sub GPXChangeTh()
        flagBusy = True ' thread状態のフラグをBusyに設定：多重起動の防止用

        ' XMLを扱うためのオブジェクトを宣言
        Dim xmlDoc As New XmlDocument()

        ' XMLを読み込み
        xmlDoc.Load(inpuFileName)

        Dim node As XmlNode = xmlDoc.DocumentElement 'XMLドキュメントからルート要素を取り出す
        ' チャイルドノードを順番に操作するので処理を分けて再帰呼び出しにする。
        CheckNode(node)

        ' 処理したXMLを書込み
        xmlDoc.Save(outputFileName)

        flagBusy = False ' thread状態のフラグをクリア：次の処理を受け付け可能に設定
    End Sub

    ' child node をチェックして tag名がeleだったら処理する
    Private Sub CheckNode(parentNode As XmlNode)

        ' チャイルドノードを順番にチェック
        For Each node As XmlNode In parentNode.ChildNodes
            If node.Name = "ele" Then
                If changeMode = 0 Then　' 0-0mに変更　1-削除
                    node.InnerText = "0"
                Else
                    parentNode.RemoveChild(node) ' ノードを削除
                End If
            Else
                ' トラック名を-NEを付け足した名称に変更
                If parentNode.Name = "trk" And node.Name = "name" Then
                    node.InnerText &= "-NE"
                End If

                ' ノードのチャイルドノードをチェック
                If node.HasChildNodes Then
                    CheckNode(node)
                End If
            End If
        Next

    End Sub

End Class
