﻿' --------------------------------------------------------------------------
' GPXファイルの標高情報を書き換える
' CopyrightⒸ 2020 チャーハン(mailto:try3dcg@nifty.com)All Rights Reserved.
' --------------------------------------------------------------------------

''' <summary>
''' メインのフォーム表示
''' </summary>
Public Class GPXNEForm

    ' GPXCHANGEクラスのインスタンス生成
    Private gpx As GPXCHANGE = New GPXCHANGE

    ' ===== 初期化処理
    ''' <summary>
    ''' ドロップダウンリストの初期化が必要なのでコンストラクタを記述する
    ''' </summary>
    Sub New()
        ' この呼び出しはデザイナーで必要です。
        InitializeComponent()

        ' InitializeComponent() 呼び出しの後で初期化を追加します。

        ' DorpDownListの初期値を設定しないと動作が未設定状態になってしまう。
        Elevation.SelectedIndex = 0     ' 0 - 0m変換　1-削除

    End Sub

    ''' <summary>
    ''' 入力ファイルのチューザー
    ''' 1) GPXファイルを選ぶ
    ''' 2) 選んだGPXファイル名をオリジナルGPXファイル名に表示する
    ''' 3) 変換後のファイル名候補を変換後のファイル名に表示する
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub FileSelect_Click(sender As Object, e As EventArgs) Handles FileSelect.Click
        Dim ofd As New OpenFileDialog()
        ofd.Filter = "GPXファイル(*.gpx)|*.gpx"
        ofd.Title = "GPXファイルを選択してください"
        ofd.FilterIndex = 1
        ofd.RestoreDirectory = True
        ofd.CheckPathExists = False

        If ofd.ShowDialog() = DialogResult.OK Then
            InputFileName.Text = ofd.FileName
            ' 変換後のファイル名は末尾にNEを付け足す。
            Dim fileNE As String = Strings.Left(ofd.FileName, ofd.FileName.Length - 4) & "NE.gpx"
            OutputFileName.Text = fileNE
        End If

    End Sub

    ''' <summary>
    ''' GPX ファイル変換実行
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub Exec_Click(sender As Object, e As EventArgs) Handles Exec.Click
        ' 多重実行の禁止
        If gpx.flagBusy Then
            MessageBox.Show("変換処理実行中です。" & vbCrLf & "しばらくお待ちください。")
            Exit Sub
        End If

        ' フォームの値を取得：直接指定でも良い気がする
        Dim inFileName As String = InputFileName.Text
        Dim outFileName As String = OutputFileName.Text
        Dim mode As Integer = Elevation.SelectedIndex    ' 0 - 0m変換　1-削除

        ' 入力ファイルが存在するかチェック
        If Not My.Computer.FileSystem.FileExists(inFileName) Then
            MessageBox.Show("参照不能なファイルが指定されました。" & vbCrLf & "変換を実行できません。")
            Exit Sub
        End If

        ' 出力ファイルが存在するか(上書き)チェック
        If My.Computer.FileSystem.FileExists(outFileName) Then
            If MessageBox.Show(outFileName & vbCrLf & "は存在します。上書きしますか？", "上書き確認", MessageBoxButtons.YesNo) = DialogResult.No Then
                Exit Sub
            End If
        End If

        '多重実行を防止するためにボタンを非活性化しておく
        Exec.Enabled = False
        Me.Cursor = Cursors.WaitCursor

        ' 変換実行
        gpx.GPXChange(inFileName, outFileName, mode)

        ' threadが終わったか 0.5秒ごとに確認する
        Me.ThTimer.Interval = 500
        Me.ThTimer.Start()

    End Sub

    ''' <summary>
    ''' threadの状態監視タイマー
    ''' threadが終了していたらFormの設定をもとに戻す後処理を行う
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub ThTimer_Tick(sender As Object, e As EventArgs) Handles ThTimer.Tick

        If Not gpx.flagBusy Then
            ' タイマー止める
            Me.ThTimer.Stop()
            'ボタンを活性化する
            Exec.Enabled = True
            '元のカーソルに戻す（通常のカーソル）
            Me.Cursor = Cursors.Default

            MessageBox.Show("変換を完了しました。")
        End If

    End Sub

End Class
